@@ -235,6 +235,9 @@ static struct cli_state *do_connect(TALLOC_CTX *ctx,
 			return NULL;
 		}
 		d_printf("Anonymous login successful\n");
+		cli_init_creds(c, "", lp_workgroup(), "");
+	} else {
+		cli_init_creds(c, username, lp_workgroup(), password);
 	}
 
 	if ( show_sessetup ) {
@@ -665,13 +668,23 @@ static char *cli_dfs_make_full_path(TALLOC_CTX *ctx,
 					struct cli_state *cli,
 					const char *dir)
 {
+	char path_sep = '\\';
+
 	/* Ensure the extrapath doesn't start with a separator. */
 	while (IS_DIRECTORY_SEP(*dir)) {
 		dir++;
 	}
 
-	return talloc_asprintf(ctx, "\\%s\\%s\\%s",
-			cli->desthost, cli->share, dir);
+	if (cli->posix_capabilities & CIFS_UNIX_POSIX_PATHNAMES_CAP) {
+		path_sep = '/';
+	}
+	return talloc_asprintf(ctx, "%c%s%c%s%c%s",
+			path_sep,
+			cli->desthost,
+			path_sep,
+			cli->share,
+			path_sep,
+			dir);
 }
 
 /********************************************************************
