@@ -652,6 +652,12 @@ static bool open_sockets_smbd(bool is_daemon, bool interactive, const char *smb_
 		FD_ZERO(&w_fds);
 		GetTimeOfDay(&now);
 
+                /* Kick off our mDNS registration. */
+                if (dns_port != 0) {
+                        dns_register_smbd(&dns_reg, dns_port, &maxfd,
+                                        &r_fds, &idle_timeout);
+                }
+
 		event_add_to_select_args(smbd_event_context(), &now,
 					 &r_fds, &w_fds, &idle_timeout,
 					 &maxfd);
@@ -1234,6 +1240,14 @@ extern void build_options(bool screen);
 	gain_root_privilege();
 	gain_root_group_privilege();
 
+	/*
+	 * Ensure we have CAP_KILL capability set on Linux,
+	 * where we need this to communicate with threads.
+	 * This is inherited by new threads, but not by new
+	 * processes across exec().
+	 */
+	set_effective_capability(KILL_CAPABILITY);
+
 	fault_setup((void (*)(void *))exit_server_fault);
 	dump_core_setup("smbd");
 
