@@ -25,6 +25,7 @@
 
 #include "includes.h"
 #include "utils/ntlm_auth.h"
+#include "smb_krb5.h"
 
 #undef DBGC_CLASS
 #define DBGC_CLASS DBGC_WINBIND
@@ -523,10 +524,10 @@ static NTSTATUS winbind_pw_check(struct ntlmssp_state *ntlmssp_state, DATA_BLOB
 {
 	static const char zeros[16] = { 0, };
 	NTSTATUS nt_status;
-	char *error_string;
+	char *error_string = NULL;
 	uint8 lm_key[8]; 
 	uint8 user_sess_key[16]; 
-	char *unix_name;
+	char *unix_name = NULL;
 
 	nt_status = contact_winbind_auth_crap(ntlmssp_state->user, ntlmssp_state->domain,
 					      ntlmssp_state->workstation,
@@ -548,7 +549,6 @@ static NTSTATUS winbind_pw_check(struct ntlmssp_state *ntlmssp_state, DATA_BLOB
 			*user_session_key = data_blob(user_sess_key, 16);
 		}
 		ntlmssp_state->auth_context = talloc_strdup(ntlmssp_state->mem_ctx, unix_name);
-		SAFE_FREE(unix_name);
 	} else {
 		DEBUG(NT_STATUS_EQUAL(nt_status, NT_STATUS_ACCESS_DENIED) ? 0 : 3, 
 		      ("Login for user [%s]\\[%s]@[%s] failed due to [%s]\n", 
@@ -557,6 +557,9 @@ static NTSTATUS winbind_pw_check(struct ntlmssp_state *ntlmssp_state, DATA_BLOB
 		       error_string ? error_string : "unknown error (NULL)"));
 		ntlmssp_state->auth_context = NULL;
 	}
+
+	SAFE_FREE(error_string);
+	SAFE_FREE(unix_name);
 	return nt_status;
 }
 
@@ -1814,7 +1817,6 @@ static void manage_ntlm_server_1_request(struct ntlm_auth_state *state,
 
 				x_fprintf(x_stdout, "Authenticated: No\n");
 				x_fprintf(x_stdout, "Authentication-Error: %s\n.\n", error_string);
-				SAFE_FREE(error_string);
 			} else {
 				static char zeros[16];
 				char *hex_lm_key;
@@ -1842,6 +1844,7 @@ static void manage_ntlm_server_1_request(struct ntlm_auth_state *state,
 					TALLOC_FREE(hex_user_session_key);
 				}
 			}
+			SAFE_FREE(error_string);
 		}
 		/* clear out the state */
 		challenge = data_blob_null;
